.. _release-0-5-2:

0.5.2
=====

Bokeh ``0.5.2`` (Aug 2014) is an incremental update:

* New Layout system
* Improved automate testing infrastructure
* AR testing, server-side downsample fixes and ISO Contours
* New "dashboard-like" example: examples/app/applet/stock_example.py
